summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJonathan Lebon <jonathan@jlebon.com>2018-07-30 10:46:58 -0400
committerAtomic Bot <atomic-devel@projectatomic.io>2018-08-01 19:59:07 +0000
commit786ee6bdec8cac24b127af7828659d71702d4f8e (patch)
treef8be4dcf4f316fb4ec9a0a8261517c34f2ba168b
parent3e96ec9811b5cfc5481f8b6b06c8d34d9a35408e (diff)
downloadostree-786ee6bdec8cac24b127af7828659d71702d4f8e.tar.gz
lib/config: Rename change-update-summary to auto-...
Mildly bikeshed, though I find the name `auto-update-summary` to be easier to grok than `change-update-summary`. I think it's because it can be read as "verb-verb-noun" rather than "noun-verb-noun". Closes: #1693 Approved by: mwleeds
-rw-r--r--man/ostree.repo-config.xml2
-rw-r--r--src/libostree/ostree-repo-commit.c2
-rw-r--r--src/libostree/ostree-repo.c16
-rw-r--r--src/ostree/ot-builtin-commit.c8
-rwxr-xr-xtests/test-auto-summary.sh6
5 files changed, 16 insertions, 18 deletions
diff --git a/man/ostree.repo-config.xml b/man/ostree.repo-config.xml
index 6149248f..5424467c 100644
--- a/man/ostree.repo-config.xml
+++ b/man/ostree.repo-config.xml
@@ -94,7 +94,7 @@ Boston, MA 02111-1307, USA.
</varlistentry>
<varlistentry>
- <term><varname>change-update-summary</varname></term>
+ <term><varname>auto-update-summary</varname></term>
<listitem><para>Boolean value controlling whether or not to
automatically update the summary file after any ref is added,
removed, or updated. This covers a superset of the cases covered by
diff --git a/src/libostree/ostree-repo-commit.c b/src/libostree/ostree-repo-commit.c
index 12ee6888..dd225e63 100644
--- a/src/libostree/ostree-repo-commit.c
+++ b/src/libostree/ostree-repo-commit.c
@@ -2202,7 +2202,7 @@ ostree_repo_commit_transaction (OstreeRepo *self,
return FALSE;
g_clear_pointer (&self->txn.collection_refs, g_hash_table_destroy);
- /* Update the summary if change-update-summary is set, because doing so was
+ /* Update the summary if auto-update-summary is set, because doing so was
* delayed for each ref change during the transaction.
*/
if (!_ostree_repo_maybe_regenerate_summary (self, cancellable, error))
diff --git a/src/ostree/ot-builtin-commit.c b/src/ostree/ot-builtin-commit.c
index ded6522f..6d295d6b 100644
--- a/src/ostree/ot-builtin-commit.c
+++ b/src/ostree/ot-builtin-commit.c
@@ -753,7 +753,7 @@ ostree_builtin_commit (int argc, char **argv, OstreeCommandInvocation *invocatio
if (!skip_commit)
{
guint64 timestamp;
- gboolean change_update_summary;
+ gboolean auto_update_summary;
if (!opt_no_bindings)
{
@@ -825,12 +825,12 @@ ostree_builtin_commit (int argc, char **argv, OstreeCommandInvocation *invocatio
goto out;
if (!ot_keyfile_get_boolean_with_default (ostree_repo_get_config (repo), "core",
- "change-update-summary", FALSE,
- &change_update_summary, error))
+ "auto-update-summary", FALSE,
+ &auto_update_summary, error))
goto out;
/* No need to update it again if we did for each ref change */
- if (opt_orphan || !change_update_summary)
+ if (opt_orphan || !auto_update_summary)
{
gboolean commit_update_summary;
diff --git a/src/libostree/ostree-repo.c b/src/libostree/ostree-repo.c
index 10f87dba..00a6b460 100644
--- a/src/libostree/ostree-repo.c
+++ b/src/libostree/ostree-repo.c
@@ -5387,7 +5387,7 @@ summary_add_ref_entry (OstreeRepo *self,
*
* It is regenerated automatically after a commit if
* `core/commit-update-summary` is set, and automatically after any ref is
- * added, removed, or updated if `core/change-update-summary` is set.
+ * added, removed, or updated if `core/auto-update-summary` is set.
*
* If the `core/collection-id` key is set in the configuration, it will be
* included as %OSTREE_SUMMARY_COLLECTION_ID in the summary file. Refs that
@@ -5593,23 +5593,21 @@ ostree_repo_regenerate_summary (OstreeRepo *self,
return TRUE;
}
/* Regenerate the summary if `core/change-update-summary` is set */
gboolean
_ostree_repo_maybe_regenerate_summary (OstreeRepo *self,
GCancellable *cancellable,
GError **error)
{
- gboolean update_summary;
+ gboolean auto_update_summary;
if (!ot_keyfile_get_boolean_with_default (self->config, "core",
- "change-update-summary", FALSE,
- &update_summary, error))
+ "auto-update-summary", FALSE,
+ &auto_update_summary, error))
return FALSE;
- if (update_summary && !ostree_repo_regenerate_summary (self,
- NULL,
- cancellable,
- error))
+ if (auto_update_summary &&
+ !ostree_repo_regenerate_summary (self, NULL, cancellable, error))
return FALSE;
return TRUE;
@@ -5593,23 +5593,21 @@ ostree_repo_regenerate_summary (OstreeRepo *self,
return TRUE;
}
-/* Regenerate the summary if `core/change-update-summary` is set */
+/* Regenerate the summary if `core/auto-update-summary` is set */
gboolean
_ostree_repo_maybe_regenerate_summary (OstreeRepo *self,
diff --git a/tests/test-auto-summary.sh b/tests/test-auto-summary.sh
index 5811fcde..3a04f184 100755
--- a/tests/test-auto-summary.sh
+++ b/tests/test-auto-summary.sh
@@ -65,7 +65,7 @@ touch repo/summary.sig
$OSTREE summary --update
assert_not_has_file repo/summary.sig
# Check that without change-update-summary set, adding, changing, or deleting a ref doesn't update the summary
$OSTREE summary --update
OLD_MD5=$(md5sum repo/summary)
$OSTREE commit -b test2 -s "A commit" test
@@ -80,8 +80,8 @@ $OSTREE refs --delete test
assert_streq "$OLD_MD5" "$(md5sum repo/summary)"
-# Check that with change-update-summary set, adding, changing, or deleting a ref updates the summary
-$OSTREE --repo=repo config set core.change-update-summary true
+# Check that with auto-update-summary set, adding, changing, or deleting a ref updates the summary
+$OSTREE --repo=repo config set core.auto-update-summary true
$OSTREE summary --update
OLD_MD5=$(md5sum repo/summary)
@@ -65,7 +65,7 @@ touch repo/summary.sig
$OSTREE summary --update
assert_not_has_file repo/summary.sig
-# Check that without change-update-summary set, adding, changing, or deleting a ref doesn't update the summary
+# Check that without auto-update-summary set, adding, changing, or deleting a ref doesn't update the summary
$OSTREE summary --update
OLD_MD5=$(md5sum repo/summary)